==> toop-edm-2.0.0-rc1-sources.jar: eu/toop/edm/jaxb/w3/skos/ObjectFactory.java <==

package eu.toop.edm.jaxb.w3.skos;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.toop.edm.jaxb.w3.skos package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _PrefLabel_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "prefLabel");
    public final static QName _AltLabel_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "altLabel");
    public final static QName _Notation_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "notation");
    public final static QName _Concept_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "Concept");
    public final static QName _Definition_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "Definition");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.toop.edm.jaxb.w3.skos
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ConceptType }
     * 
     * @return
     *     The created ConceptType object and never <code>null</code>.
     */
    @Nonnull
    public ConceptType createConceptType() {
        return new ConceptType();
    }

    /**
     * Create an instance of {@link DefinitionType }
     * 
     * @return
     *     The created DefinitionType object and never <code>null</code>.
     */
    @Nonnull
    public DefinitionType createDefinitionType() {
        return new DefinitionType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "prefLabel")
    @Nonnull
    public JAXBElement<String> createPrefLabel(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_PrefLabel_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "altLabel")
    @Nonnull
    public JAXBElement<String> createAltLabel(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_AltLabel_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "notation")
    @Nonnull
    public JAXBElement<Object> createNotation(
        @Nullable
        final Object value) {
        return new JAXBElement<Object>(_Notation_QNAME, Object.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ConceptType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ConceptType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "Concept")
    @Nonnull
    public JAXBElement<ConceptType> createConcept(
        @Nullable
        final ConceptType value) {
        return new JAXBElement<ConceptType>(_Concept_QNAME, ConceptType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DefinitionType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link DefinitionType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "Definition")
    @Nonnull
    public JAXBElement<DefinitionType> createDefinition(
        @Nullable
        final DefinitionType value) {
        return new JAXBElement<DefinitionType>(_Definition_QNAME, DefinitionType.class, null, value);
    }

}

==> toop-edm-2.1.1-sources.jar: eu/toop/edm/jaxb/w3/skos/ObjectFactory.java <==

package eu.toop.edm.jaxb.w3.skos;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.toop.edm.jaxb.w3.skos package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _PrefLabel_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "prefLabel");
    public final static QName _AltLabel_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "altLabel");
    public final static QName _Notation_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "notation");
    public final static QName _Name_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "name");
    public final static QName _Concept_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "Concept");
    public final static QName _ConceptScheme_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "ConceptScheme");
    public final static QName _Definition_QNAME = new QName("http://www.w3.org/2004/02/skos/core#", "Definition");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.toop.edm.jaxb.w3.skos
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ConceptType }
     * 
     * @return
     *     The created ConceptType object and never <code>null</code>.
     */
    @Nonnull
    public ConceptType createConceptType() {
        return new ConceptType();
    }

    /**
     * Create an instance of {@link ConceptSchemeType }
     * 
     * @return
     *     The created ConceptSchemeType object and never <code>null</code>.
     */
    @Nonnull
    public ConceptSchemeType createConceptSchemeType() {
        return new ConceptSchemeType();
    }

    /**
     * Create an instance of {@link DefinitionType }
     * 
     * @return
     *     The created DefinitionType object and never <code>null</code>.
     */
    @Nonnull
    public DefinitionType createDefinitionType() {
        return new DefinitionType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "prefLabel")
    @Nonnull
    public JAXBElement<String> createPrefLabel(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_PrefLabel_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "altLabel")
    @Nonnull
    public JAXBElement<String> createAltLabel(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_AltLabel_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "notation")
    @Nonnull
    public JAXBElement<Object> createNotation(
        @Nullable
        final Object value) {
        return new JAXBElement<Object>(_Notation_QNAME, Object.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "name")
    @Nonnull
    public JAXBElement<String> createName(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_Name_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ConceptType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ConceptType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "Concept")
    @Nonnull
    public JAXBElement<ConceptType> createConcept(
        @Nullable
        final ConceptType value) {
        return new JAXBElement<ConceptType>(_Concept_QNAME, ConceptType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ConceptSchemeType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ConceptSchemeType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "ConceptScheme")
    @Nonnull
    public JAXBElement<ConceptSchemeType> createConceptScheme(
        @Nullable
        final ConceptSchemeType value) {
        return new JAXBElement<ConceptSchemeType>(_ConceptScheme_QNAME, ConceptSchemeType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DefinitionType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link DefinitionType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2004/02/skos/core#", name = "Definition")
    @Nonnull
    public JAXBElement<DefinitionType> createDefinition(
        @Nullable
        final DefinitionType value) {
        return new JAXBElement<DefinitionType>(_Definition_QNAME, DefinitionType.class, null, value);
    }

}
